@@ -8,7 +8,7 @@ class not_(Matcher):
         self._matcher = matcher
 
     def _match(self, subject):
-        return not self._matcher._match(subject)
+        return self._matcher._match_negated(subject)
 
-    def _description(self, subject):
-        return 'not ' + self._matcher._description(subject)
+    def __repr__(self):
+        return 'not {0!r}'.format(self._matcher)
